@@ -34,4 +34,28 @@ class CdnSites(BaseObject):
     def delete(self):
         response = self._client.delete("/cdn/v1/stacks/{}/sites/{}".format(self._parent_id, self.id))
         response.raise_for_status()
-        return self
\ No newline at end of file
+        return self
+
+    def purge(self, url, recursive = True, invalidateOnly = False, purgeAllDynamic = False, headers = [], purgeSelector = []):
+        purgeSelectors = ["selectorType","selectorName","selectorValue", "selectorValueDelimter"]
+
+        for value in purgeSelector:
+            if not value in purgeSelectors:
+                raise ValueError(f"{value} is not a valid purgeSelector: {purgeSelectors}")
+
+        data = {
+            "items": [
+                {
+                    "url" : url,
+                    "recursive" : recursive,
+                    "headers" : headers,
+                    "invalidateOnly" : invalidateOnly,
+                    "purgeSelector" : purgeSelector
+                }
+            ]
+        }
+        
+        response = self._client.post("/cdn/v1/stacks/{}/purge".format(self._parent_id), json = data)
+        response.raise_for_status()
+
+        return self.loaddict(response.json())
